Total Value to Paid-In Capital (also known as the 'Investment Multiple') is a
measure of the performance of a private equity fund. It represents the total
value of a fund relative to the amount of capital paid into the fund to date.
The total value of a fund is the sum of realised value (all distributions made
to investors to date) plus the unrealised value (residual value of investments)
still held by the fund.

Formula: (Distributed Capital + residual Value) / Paid-In Capital

See also:
- <https://www.moonfare.com/glossary/total-value-to-paid-in-capital-tvpi>
- <https://financestu.com/tvpi-vs-moic/>
